![Tests](https://github.com/zerotier/ztchooks-py/actions/workflows/python.yaml/badge.svg)


# ZTC Hooks for Python3

`ztchooks` provides primitives for serializing and verifying hooks fired from [ZeroTier Central](https://my.zerotier.com)

Webhook signatures from ZeroTier Central are in the HTTP header field: `X-ZTC-Signature`

Example Flask app can be found in the `example/` subfolder

# License

Copyright 2023 ZeroTier, Inc. All rights reserved.  Licensed under the Mozilla Public License Version 2.0.  See the `LICENSE` file for the full license text.
